# Sudokuku

[![Python Version](https://img.shields.io/pypi/pyversions/sudokuku?style=flat-square)](https://pypi.org/project/sudokuku)
[![License](https://img.shields.io/pypi/l/sudokuku?style=flat-square)](https://github.com/jonasstrube/sudokuku/blob/main/LICENSE)

[![PyPI Package Version](https://shields.io/pypi/v/sudokuku?style=flat-square)](https://pypi.org/project/sudokuku)
[![PyPI Downloads](https://img.shields.io/pypi/dm/sudokuku?style=flat-square)](https://pypi.org/project/sudokuku)
![GitHub Repository Size](https://shields.io/github/repo-size/jonasstrube/sudokuku?style=flat-square)
![GitHub Last Commit](https://img.shields.io/github/last-commit/jonasstrube/sudokuku?style=flat-square)

A package for solving sudokus
